@@ -72,39 +72,20 @@ class Catalog:
         resource: ResourceItem = [
             r for r in data_source.resources if r.name == resource_name
         ][0]
+        all_paths = self.get_all_directories(resource)
         if resource.last_processed:
             date_segment = resource.date_segment if resource.date_segment else 0
-
             date_format = resource.date_format if resource.date_format else "%Y-%m-%d"
             last_processed = resource.last_processed.get_last_processed(environment)
-            all_paths = self.get_all_directories(resource, last_processed)
             path_parts = list(
                 filter(None, last_processed.replace("s3:/", "").split("/"))
             )
-
-            if isinstance(date_segment, int):
-                last_processed_date = datetime.strptime(
-                    path_parts[date_segment], date_format
-                )
-            if isinstance(date_segment, list):
-                last_processed_date_str = ""
-                for segment in date_segment:
-                    last_processed_date_str = (
-                        last_processed_date_str + path_parts[segment]
-                    )
-                last_processed_date = datetime.strptime(
-                    last_processed_date_str, date_format
-                )
-
+            last_processed_date = datetime.strptime(
+                path_parts[date_segment], date_format
+            )
             for path in all_paths:
                 path_parts = list(filter(None, path.replace("s3:/", "").split("/")))
-                if isinstance(date_segment, int):
-                    path_date = datetime.strptime(path_parts[date_segment], date_format)
-                if isinstance(date_segment, list):
-                    path_date_str = ""
-                    for segment in date_segment:
-                        path_date_str = path_date_str + path_parts[segment]
-                    path_date = datetime.strptime(path_date_str, date_format)
+                path_date = datetime.strptime(path_parts[date_segment], date_format)
                 if path_date > last_processed_date:
                     paths_to_process[path_date] = path
 
@@ -115,7 +96,7 @@ class Catalog:
             return []
 
     @staticmethod
-    def get_all_directories(resource: ResourceItem, last_processed: str) -> List[str]:
+    def get_all_directories(resource: ResourceItem) -> List[str]:
         full_path = resource.full_path
         all_paths: List[str] = []
         if full_path.startswith("s3://"):
@@ -128,18 +109,13 @@ class Catalog:
                 if (
                     len(list(filter(None, s3_file["Key"].split("/"))))
                     == resource.date_segment
-                    or last_processed.split("/")[-1] == s3_file["Key"].split("/")[-1]
                 ):
                     all_paths.append(f"s3://{bucket}/{s3_file['Key']}")
             return all_paths
         else:
-            paths = [
-                os.path.join(dp, f)
-                for dp, dn, fn in os.walk(os.path.expanduser(full_path))
-                for f in fn
-            ]
+            paths = os.listdir(full_path)
             for path in paths:
-                all_paths.append(path)
+                all_paths.append(os.path.join(full_path, path))
             return all_paths
 
     def get_all_data_sources(
