@@ -35,9 +35,6 @@ class ResourceItem:
         self.last_processed = None
         if hasattr(content, "last_processed") and content.last_processed is not None:
             self.last_processed = LastProcessed(content.last_processed, environment)
-        self.path_extension = None
-        if hasattr(content, "path_extension") and content.path_extension is not None:
-            self.path_extension = content.path_extension
 
     @property
     def full_path_slug(self) -> str:
@@ -51,10 +48,7 @@ class ResourceItem:
 
     def matches_path(self, path: str) -> bool:
         if self.full_path_slug and self.full_path_slug in path:
-            if self.path_extension:
-                return path.endswith(self.path_extension)
-            else:
-                return True
+            return True
         return False
 
     @property
